| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
Patat.Presentation.SpeakerNotes
Synopsis
- data SpeakerNotes
- parse :: Block -> Maybe SpeakerNotes
- toText :: SpeakerNotes -> Text
- remove :: [Block] -> [Block]
- split :: [Block] -> (SpeakerNotes, [Block])
- partition :: [Block] -> (SpeakerNotes, [Block])
- data Settings
- data Handle
- with :: Settings -> (Handle -> IO a) -> IO a
- write :: Handle -> EncodingFallback -> SpeakerNotes -> IO ()
Documentation
data SpeakerNotes Source #
Instances
| Monoid SpeakerNotes Source # | |
Defined in Patat.Presentation.SpeakerNotes Methods mempty :: SpeakerNotes # mappend :: SpeakerNotes -> SpeakerNotes -> SpeakerNotes # mconcat :: [SpeakerNotes] -> SpeakerNotes # | |
| Semigroup SpeakerNotes Source # | |
Defined in Patat.Presentation.SpeakerNotes Methods (<>) :: SpeakerNotes -> SpeakerNotes -> SpeakerNotes # sconcat :: NonEmpty SpeakerNotes -> SpeakerNotes # stimes :: Integral b => b -> SpeakerNotes -> SpeakerNotes # | |
| Show SpeakerNotes Source # | |
Defined in Patat.Presentation.SpeakerNotes Methods showsPrec :: Int -> SpeakerNotes -> ShowS # show :: SpeakerNotes -> String # showList :: [SpeakerNotes] -> ShowS # | |
| Eq SpeakerNotes Source # | |
Defined in Patat.Presentation.SpeakerNotes | |
toText :: SpeakerNotes -> Text Source #
split :: [Block] -> (SpeakerNotes, [Block]) Source #
Take all speaker notes from the front of the list. Return those and the remaining blocks.
partition :: [Block] -> (SpeakerNotes, [Block]) Source #
Partition the list into speaker notes and other blocks.
write :: Handle -> EncodingFallback -> SpeakerNotes -> IO () Source #